<?php

declare(strict_types=1);

namespace Dedi\SyliusMailAdminPlugin\DependencyInjection;

use Symfony\Component\Config\FileLocator;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\DependencyInjection\Extension\Extension;
use Symfony\Component\DependencyInjection\Extension\PrependExtensionInterface;
use Symfony\Component\DependencyInjection\Loader\XmlFileLoader;

final class DediSyliusMailAdminExtension extends Extension implements PrependExtensionInterface
{
    /**
     * {@inheritdoc}
     */
    public function load(array $config, ContainerBuilder $container): void
    {
        $config = $this->processConfiguration($this->getConfiguration([], $container), $config);
        $loader = new XmlFileLoader($container, new FileLocator(__DIR__ . '/../Resources/config'));

        $loader->load('services.xml');
    }

    public function prepend(ContainerBuilder $container)
    {
        $configs = $container->getExtensionConfig($this->getAlias());
        $config = $this->processConfiguration(new Configuration(), $configs);

        if ($config['autoconfigure_fos_ckeditor_form_themes']) {
            $container->prependExtensionConfig('twig', [
                'form_themes' => [
                    '@FOSCKEditor/Form/ckeditor_widget.html.twig',
                ],
            ]);
        }

        $container->prependExtensionConfig('fos_ck_editor', [
            'configs' => [
                'dedi_mail_admin_plugin_config' => [
                    'toolbar' => [
                        ['JustifyLeft', 'JustifyCenter', 'JustifyRight', 'JustifyBlock'],
                        ['TextColor', 'FontSize'],
                        ['Bold', 'Italic', 'Underline'],
                        ['NumberedList', 'BulletedList'],
                        ['Link', 'Unlink'],
                    ],
                ],
            ],
        ]);
    }
}
